@@ -4,7 +4,6 @@ from typing import Dict
 
 from logzero import logger as log  # pylint: disable=W0611
 from logzero import LogFormatter, formatter as set_formatter
-from typeguard import typechecked
 
 
 DEFAULT_FMT = '%(color)s[%(levelname)1.1s %(asctime)s]%(end_color)s %(message)s'
@@ -13,7 +12,6 @@ DEBUG_FMT = ('%(color)s[%(levelname)1.1s %(asctime)s PID:%(process)d(%(processNa
 
 
 class DefaultLogFormatter(LogFormatter):
-    @typechecked
     def __init__(self, formatters: Dict[int, str],
                  default_format: str = DEFAULT_FMT,
                  date_format: str = '%Y-%m-%d %H:%M:%S%z'):
